==> falak-0.1.5.tgz: package/framework/commands/new-component.js <==
const { fs } = require('./../bootstrap/modules');

function createComponent(componentName, command) {
    let appName = command.options.app || APP_NAME;

    if (componentName.startsWith('pages') && ! componentName.endsWith('-page')) {
        componentName += '-page';
    }

    let componentSegments = componentName.split('/');

    let defaultSelector = componentSegments.end();

    let selector = command.options.selector || defaultSelector;

    let component = (command.options.component || defaultSelector).toCamelCase().ucfirst();

    let componentPath = ROOT + `/src/${appName}/components/${componentName}`;

    if (fs.isDir(componentPath)) {
        die(`${cli.redBright(componentName)} component already exists!`);
    }

    echo(`${cli.yellow('Creating')} ${cli.green(componentName)} component...`);

    // first we will copy the component
    fs.copy(FRAMEWORK_RESOURCES_PATH + '/ui-component', componentPath);

    // now we will update all files to replace the placeholder with component details
    handleJsFiles(command, componentPath, component, selector);
    handleScssFiles(componentPath, selector);
    updatePackage(componentPath, appName, componentName);

    if (command.route) {
        addPageRoute(command.route, component, appName);
    }

    echo(`${cli.cyan(componentName)} ${cli.green('component has been created successfully.')}`);
}

function addPageRoute(route, component, appName) {
    let routingJsPath = ROOT + `/src/${appName}/components/routing.js`;

    let routingJsContnet = fs.get(routingJsPath);

    routingJsContnet += `\r\n// ${component} page\r\n Router.add('${route}', ${component});`;

    fs.put(routingJsPath, routingJsContnet);
}

function updatePackage(componentPath, appName, componentName) {
    if (componentPath.includes('pages') || componentPath.includes('layout')) return;

    let packagePath = ROOT + `/src/${appName}/package.json`;

    let $package = fs.getJson(packagePath);

    $package.components.push(componentName);

    fs.putJson(packagePath, $package);
}

function handleJsFiles(command, componentPath, component, selector) {
    // handle the compiler file
    let tagHandler = fs.get(componentPath + '/compiler/components/tag-handler.js');

    let isUnique = command.options.unique;

    let isChildComponent = command.options.asChild;

    let parentComponentName,
        parentComponentClassPath;

    if (isChildComponent) {
        parentComponentName = 'ChildComponent';
        parentComponentClassPath = 'CHILD_COMPONENT_CLASS_PATH';
    } else {
        parentComponentName = 'Component';
        parentComponentClassPath = 'COMPONENT_CLASS_PATH';
    }

    tagHandler = tagHandler.replace('PARENT_COMPONENT_PATH', parentComponentClassPath)
        .replaceAll('ParentComponent', parentComponentName)
        .replace('isChildFlag', isChildComponent ? 'true' : 'false')
        .replace('ComponentHandler', component)
        .replaceAll('NewCustom', component)
        .replace('tag-name', selector)
        .replace('component-name', selector)
        .replaceAll('isUniqueComponent', isUnique ? 'true' : 'false');

    fs.put(componentPath + `/compiler/components/${selector}.js`, tagHandler);

    fs.unlink(componentPath + '/compiler/components/tag-handler.js');

    let htmlFilePath = componentPath + '/component-name.component.html';

    let htmlFileContent = fs.get(htmlFilePath);

    htmlFileContent = htmlFileContent.replace('%component', selector);

    fs.put(htmlFilePath, htmlFileContent);

    // rename html file
    fs.rename(htmlFilePath, componentPath + `/${selector}.component.html`);

    // handle the js file
    let jsFile = fs.get(componentPath + '/component-name.component.js');
    fs.unlink(componentPath + '/component-name.component.js');

    if (isChildComponent) return; // do not set js file for the component if it is child

    jsFile = jsFile.replace('class ComponentHandler', `class ${component}`);

    let pageName = '',
        pageTitle = '';

    if (command.route) {
        pageName = `this.name = '${selector.replace('-page', '')}';`;
        pageTitle = `this.title = trans('${selector}');`;
    }

    jsFile = jsFile.replace('pageName', pageName)
        .replace('pageTitle', pageTitle);

    fs.put(componentPath + `/${selector}.component.js`, jsFile);
}


/**
 * Create scss files
 *
 * @param  string $component
 * @return void
 */
function handleScssFiles(componentPath, selector) {
    // rename scss file
    let scssFilePath = componentPath + `/${selector}.component.scss`;
    fs.rename(componentPath + '/component-name.component.scss', scssFilePath);
    let content = fs.get(scssFilePath).replace('placeholder', selector);

    fs.put(scssFilePath, content);
}

module.exports = function (command) {
    if (command.asChild && command.route) {
        die(`Can't use ${cli.redBright('--as-child')} and ${cli.redBright('--route')} for same component`);
    }

    if (command.components.length > 1 && command.route) {
        die(`Can't use ${cli.redBright('--route')} with more than one component`);
    }

    for (let componentName of command.components) {
        createComponent(componentName, command);
    }

    die();
}

==> falak-0.1.22.tgz: package/framework/commands/new-component.js <==
const { fs } = require('./../bootstrap/modules');

function createComponent(componentName, command) {
    let appName = command.options.app || APP_NAME;

    if (componentName.startsWith('pages') && !componentName.endsWith('-page')) {
        componentName += '-page';
    }

    let componentSegments = componentName.split('/');

    let defaultSelector = componentSegments.end();

    let selector = command.options.selector || defaultSelector;

    let component = (command.options.component || defaultSelector).toCamelCase().ucfirst();

    let componentPath = ROOT + `/src/${appName}/components/${componentName}`;

    if (fs.isDir(componentPath)) {
        die(`${cli.redBright(componentName)} component already exists!`);
    }

    echo(`${cli.yellow('Creating')} ${cli.green(componentName)} component...`);

    // first we will copy the component
    fs.copy(FRAMEWORK_RESOURCES_PATH + '/ui-component', componentPath);

    // now we will update all files to replace the placeholder with component details
    handleJsFiles(command, componentPath, component, selector);
    handleScssFiles(componentPath, selector);
    updatePackage(componentPath, appName, componentName);

    if (command.route) {
        addPageRoute(command.route, component, appName);
    }

    echo(`${cli.cyan(componentName)} ${cli.green('component has been created successfully.')}`);
}

function addPageRoute(route, component, appName) {
    let routingJsPath = ROOT + `/src/${appName}/components/routing.js`;

    let routingJsContnet = fs.get(routingJsPath);

    routingJsContnet += `\r\n// ${component} page\r\n Router.add('${route}', ${component});`;

    fs.put(routingJsPath, routingJsContnet);
}

function updatePackage(componentPath, appName, componentName) {
    if (componentPath.includes('pages') || componentPath.includes('layout')) return;

    let packagePath = ROOT + `/src/${appName}/package.json`;

    let $package = fs.getJson(packagePath);

    $package.components.push(componentName);

    fs.putJson(packagePath, $package);
}

function handleJsFiles(command, componentPath, component, selector) {
    // handle the compiler file
    let tagHandler = fs.get(componentPath + '/compiler/components/tag-handler.js');

    let isUnique = command.options.unique;

    let isChildComponent = command.options.asChild;

    let parentComponentName,
        parentComponentClassPath;

    if (isChildComponent) {
        parentComponentName = 'ChildComponent';
        parentComponentClassPath = 'CHILD_COMPONENT_CLASS_PATH';
    } else {
        parentComponentName = 'Component';
        parentComponentClassPath = 'COMPONENT_CLASS_PATH';
    }

    tagHandler = tagHandler.replace('PARENT_COMPONENT_PATH', parentComponentClassPath)
        .replaceAll('ParentComponent', parentComponentName)
        .replace('isChildFlag', isChildComponent ? 'true' : 'false')
        .replace('ComponentHandler', component)
        .replaceAll('NewCustom', component)
        .replace('tag-name', selector)
        .replace('component-name', selector)
        .replaceAll('isUniqueComponent', isUnique ? 'true' : 'false');

    fs.put(componentPath + `/compiler/components/${selector}.js`, tagHandler);

    fs.unlink(componentPath + '/compiler/components/tag-handler.js');

    let htmlFilePath = componentPath + '/component-name.component.html';

    let htmlFileContent = fs.get(htmlFilePath);

    htmlFileContent = htmlFileContent.replace('%component', selector);

    fs.put(htmlFilePath, htmlFileContent);

    // rename html file
    fs.rename(htmlFilePath, componentPath + `/${selector}.component.html`);

    // handle the js file
    let jsFile = fs.get(componentPath + '/component-name.component.js');
    fs.unlink(componentPath + '/component-name.component.js');

    if (isChildComponent) return; // do not set js file for the component if it is child

    jsFile = jsFile.replace('class ComponentHandler', `class ${component}`);

    let pageName = '',
        pageTitle = '';

    if (command.options) {
        pageName = `this.name = '${selector.replace('-page', '')}';`;
    }

    if (command.options.title || command.route) {
        let title = command.options.title ? `'${command.options.title}'` : `trans('${selector}')`;
        pageTitle = `this.title = ${title};`;
    }

    jsFile = jsFile.replace('pageName', pageName)
        .replace('pageTitle', pageTitle);

    fs.put(componentPath + `/${selector}.component.js`, jsFile);
}


/**
 * Create scss files
 *
 * @param  string $component
 * @return void
 */
function handleScssFiles(componentPath, selector) {
    // rename scss file
    let scssFilePath = componentPath + `/${selector}.component.scss`;
    fs.rename(componentPath + '/component-name.component.scss', scssFilePath);
    let content = fs.get(scssFilePath).replace('placeholder', selector);

    fs.put(scssFilePath, content);
}

module.exports = function (command) {
    if (command.asChild && command.route) {
        die(`Can't use ${cli.redBright('--as-child')} and ${cli.redBright('--route')} for same component`);
    }

    if (command.components.length > 1 && command.route) {
        die(`Can't use ${cli.redBright('--route')} with more than one component`);
    }

    for (let componentName of command.components) {
        createComponent(componentName, command);
    }

    die();
}
